@@ -59,7 +59,9 @@ class GetSSMParamByPathTask(tasks.PuppetTask):
             paginator = ssm.get_paginator("get_parameters_by_path")
             for page in paginator.paginate(Path=self.path, Recursive=self.recursive):
                 for parameter in page.get("Parameters", []):
-                    parameters[parameter.get("Name")] = parameter
+                    parameters[parameter.get("Name")] = dict(
+                        Value=parameter.get("Value")
+                    )
 
         self.write_output(parameters)
 
@@ -217,8 +219,14 @@ class PuppetTaskWithParameters(tasks.PuppetTask):
                 parameter_is_in_hub = str(
                     param_details.get("ssm").get("account_id", "")
                 ) == str(self.puppet_account_id)
+                is_in_spoke_mode = constants.EXECUTION_MODE_SPOKE == self.execution_mode
+                should_execute_in_spoke_mode = (
+                    constants.EXECUTION_MODE_SPOKE == self.execution
+                )
+
                 if (
-                    constants.EXECUTION_MODE_SPOKE == self.execution_mode
+                    is_in_spoke_mode
+                    and should_execute_in_spoke_mode
                     and parameter_is_in_hub
                 ):
                     klass = GetSSMParamFromManifestTask
